pub enum PythonSurfaceState {
Present,
Absent,
}Expand description
Whether one public Python surface is implemented by the checked profile.
Variants
Present
The checked matrix exercises this member and the profile exposes it.
Absent
The profile deliberately has no implementation for this member.