pub fn install_python_core_profile(
cx: &mut Cx,
registry: &mut ProfileRegistry,
) -> Result<LanguageProfile>Expand description
Install the profile. Collection is a runtime policy option, never a load prerequisite.
pub fn install_python_core_profile(
cx: &mut Cx,
registry: &mut ProfileRegistry,
) -> Result<LanguageProfile>Install the profile. Collection is a runtime policy option, never a load prerequisite.