pub fn python_core_profile() -> LanguageProfileExpand description
Build the Python core profile, including capabilities and inspectable gaps.
pub fn python_core_profile() -> LanguageProfileBuild the Python core profile, including capabilities and inspectable gaps.