pub struct DynamicPython { /* private fields */ }Expand description
Capability-gated Python eval and exec with no ambient authority.
Implementations
Sourceimpl DynamicPython
impl DynamicPython
Sourcepub fn with_codec(codec: Symbol) -> Self
pub fn with_codec(codec: Symbol) -> Self
Build the dynamic surface for an installed compatible source codec.