pub type PythonExceptionRef = ManagedHandle;Expand description
Stable handle for an exception object owned by PythonExceptions.
Aliased Type
pub struct PythonExceptionRef { /* private fields */ }pub type PythonExceptionRef = ManagedHandle;Stable handle for an exception object owned by PythonExceptions.
pub struct PythonExceptionRef { /* private fields */ }