pub type PythonFunction = FunctionInstance<PythonBodyPolicy>;Expand description
A Python function whose identity, plan, captures, callable surface, and reachability are supplied exclusively by the shared function and managed organs.
Aliased Type
pub struct PythonFunction { /* private fields */ }